-------------------------------------------------------
--
--  OrchestratorReporting - Partition Tables Maintenance
--
-------------------------------------------------------
DECLARE @JobID uniqueidentifier
DECLARE @Database varchar(255)
Set @Database = '<INSERT REPORTING DB NAME HERE>'

SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'OrchestratorReporting - Partition Tables Maintenance')       

IF (@JobID IS NOT NULL)    
BEGIN  
    -- Delete the job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'OrchestratorReporting - Partition Tables Maintenance' 
    SET @JobID = NULL
END 

-- Add the job
EXEC msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , 
                         @job_name = N'OrchestratorReporting - Partition Tables Maintenance',
			             @enabled = 1,                               
                         @description = N'It runs database maintenance tasks.',
			             @notify_level_eventlog = 2

-- step 1. Create new partition tables, update views, and drop old partitions
EXEC msdb.dbo.sp_add_jobstep @job_id = @JobID, 
                    @step_name = N'Maintain Partition Tables',                               
                    @subsystem = 'TSQL',                                                   
                    @command = 'EXEC [PartitionTableMaintenance]', 
                    @database_name = @Database,                                            
                    @retry_attempts = 0,                                                    
                    @retry_interval = 0,                                                    
                    @on_success_action = 3,                                                 
                    @on_fail_action = 2                                                     

-- step 2. validate partition tables
EXEC msdb.dbo.sp_add_jobstep @job_id = @JobID, 
                    @step_name = N'Validate Partiion Tables',
                    @subsystem = 'TSQL',                               
                    @command = 'EXEC [ValidatePartitionedTables]', 
                    @database_name = @Database,                                            
                    @retry_attempts = 0,
                    @retry_interval = 0,
                    @on_success_action = 1,
                    @on_fail_action = 2

-- Add the job schedules
-- It runs every day at 1:30AM.
EXECUTE msdb.dbo.sp_add_jobschedule @job_id = @JobID, 
                        @name = N'OrchestratorReporting Partitioned Table Maintenance Schedule',  
                        @freq_type = 4,                                                     
                        @freq_interval = 1,                                                
                        @freq_recurrence_factor = 0,                                        
                        @freq_subday_type = 0,                                              
                        @freq_subday_interval = 0,                                          
                        @active_start_time = 013000                                         

-- Add the Target Servers
EXECUTE msdb.dbo.sp_add_jobserver @job_id = @JobID, 
                                  @server_name = N'(local)' 


GO



-------------------------------------------------------
--
--  OrchestratorReporting - Non-Partitioned Tables Maintenance
--
-------------------------------------------------------
DECLARE @JobID uniqueidentifier
DECLARE @Database varchar(255)
Set @Database = '<INSERT REPORTING DB NAME HERE>'

SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'OrchestratorReporting - Non-Partitioned Tables Maintenance')       

IF (@JobID IS NOT NULL)    
BEGIN  
    -- Delete the job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'OrchestratorReporting - Non-Partitioned Tables Maintenance' 
    SET @JobID = NULL
END 

-- Add the job
EXEC msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , 
                    @job_name = N'OrchestratorReporting - Non-Partitioned Tables Maintenance',
   			        @enabled = 1,                               
                    @description = N'It runs database maintenance tasks.',
			        @notify_level_eventlog = 2

-- step 1. Create new partition tables, update views, and drop old partitions
EXEC msdb.dbo.sp_add_jobstep @job_id = @JobID, 
                    @step_name = N'Maintain Non-Partition Tables',                               
                    @subsystem = 'TSQL',                                                   
                    @command = 'EXEC [GroomNonPartitionedTables]', 
                    @database_name = @Database,                                            
                    @retry_attempts = 0,                                                   
                    @on_success_action = 1,                                                 
                    @on_fail_action = 2                                                     

-- Add the job schedules
-- It runs every hour.
EXECUTE msdb.dbo.sp_add_jobschedule @job_id = @JobID, 
                        @name = N'OrchestratorReporting Non-Partitioned Tables Maintenance Schedule',  
                        @freq_type = 4,                                                     
                        @freq_interval = 1,                                                
                        @freq_recurrence_factor = 0,                                        
                        @freq_subday_type = 8,                                              
                        @freq_subday_interval = 1                                         

-- Add the Target Servers
EXECUTE msdb.dbo.sp_add_jobserver @job_id = @JobID, 
                                  @server_name = N'(local)' 

GO



-------------------------------------------------------
--
--  OrchestratorReporting - Copy Data From Non-Partitioned Tables to Monthly Tables
--
-------------------------------------------------------
DECLARE @JobID uniqueidentifier
DECLARE @Database varchar(255)
Set @Database = '<INSERT REPORTING DB NAME HERE>'

SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'OrchestratorReporting - Copy Data to Monthly Tables')       

IF (@JobID IS NOT NULL)    
BEGIN  
    -- Delete the job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'OrchestratorReporting - Copy Data to Monthly Tables'
    SET @JobID = NULL
END 

-- Add the job
EXEC msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , 
                         @job_name = N'OrchestratorReporting - Copy Data to Monthly Tables',
			 @enabled = 1,                               
                         @description = N'It archives data from non-partitioned tables to monthly tables.',
			 @notify_level_eventlog = 2

-- step 1. Copy Events to monthly tables
EXEC msdb.dbo.sp_add_jobstep @job_id = @JobID, 
                    @step_name = N'Copy Events to Monthly Tables',                               
                    @subsystem = 'TSQL',                                                   
                    @command = 'EXEC [ArchiveEvents] 3', 
                    @database_name = @Database,                                            
                    @retry_attempts = 0,                                                    
                    @retry_interval = 0,                                                    
                    @on_success_action = 3,                                                 
                    @on_fail_action = 2   
                    
-- step 2. Copy Alerts to monthly tables
EXEC msdb.dbo.sp_add_jobstep @job_id = @JobID, 
                    @step_name = N'Copy Alerts to Monthly Tables',                               
                    @subsystem = 'TSQL',                                                   
                    @command = 'EXEC [ArchiveAlerts] 3', 
                    @database_name = @Database,                                            
                    @retry_attempts = 0,                                                    
                    @retry_interval = 0,                                                    
                    @on_success_action = 3,                                                 
                    @on_fail_action = 2     
                      
-- step 3. Copy Incidents to monthly tables
EXEC msdb.dbo.sp_add_jobstep @job_id = @JobID, 
                    @step_name = N'Copy Incidents to Monthly Tables',                               
                    @subsystem = 'TSQL',                                                   
                    @command = 'EXEC [ArchiveIncidents] 3', 
                    @database_name = @Database,                                            
                    @retry_attempts = 0,                                                    
                    @retry_interval = 0,                                                    
                    @on_success_action = 3,                                                 
                    @on_fail_action = 2                                                 

-- step 4. Copy change request to monthly tables
EXEC msdb.dbo.sp_add_jobstep @job_id = @JobID, 
                    @step_name = N'Copy change requests to Monthly Tables',                               
                    @subsystem = 'TSQL',                                                   
                    @command = 'EXEC [ArchiveChangeRequests] 3', 
                    @database_name = @Database,                                            
                    @retry_attempts = 0,                                                    
                    @retry_interval = 0,                                                    
                    @on_success_action = 1,                                                 
                    @on_fail_action = 2                                                 

-- Add the job schedules
-- It runs every 5 minutes.
EXECUTE msdb.dbo.sp_add_jobschedule @job_id = @JobID, 
                        @name = 'OrchestratorReporting Copy Data to Monthly Tables Schedule',  
                        @freq_type = 4,                                                     
                        @freq_interval = 1,                                                
                        @freq_recurrence_factor = 0,                                        
                        @freq_subday_type = 4,                                              
                        @freq_subday_interval = 5, 
                        @active_start_time = 0,
                        @freq_relative_interval = 0,
                        @active_end_time = 235959

-- Add the Target Servers
EXECUTE msdb.dbo.sp_add_jobserver @job_id = @JobID, 
                                  @server_name = N'(local)' 

GO




-------------------------------------------------------
--
--  OrchestratorReporting - Summarize Performance Metrics
--
-------------------------------------------------------
DECLARE @JobID uniqueidentifier
DECLARE @Database varchar(255)
Set @Database = '<INSERT REPORTING DB NAME HERE>'

SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'OrchestratorReporting - Summarize Performance Metrics')       

IF (@JobID IS NOT NULL)    
BEGIN  
    -- Delete the job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'OrchestratorReporting - Summarize Performance Metrics' 
    SET @JobID = NULL
END 

-- Add the job
EXEC msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , 
                    @job_name = N'OrchestratorReporting - Summarize Performance Metrics',
   			        @enabled = 1,                               
                    @description = N'It summarizes performance data.',
			        @notify_level_eventlog = 2

-- step 1. Summarize Performance Metrics by Hour
EXEC msdb.dbo.sp_add_jobstep @job_id = @JobID, 
                    @step_name = N'Summarize Performance Metrics by Hour',
                    @subsystem = 'TSQL',                                                   
                    @command = 'EXEC [SummarizeMetricsBySystemByHour]', 
                    @database_name = @Database,                                            
                    @retry_attempts = 0,                                                    
                    @retry_interval = 0,                                                    
                    @on_success_action = 3,                                                 
                    @on_fail_action = 2                                                     

-- step 2. validate partition tables
EXEC msdb.dbo.sp_add_jobstep @job_id = @JobID, 
                    @step_name = N'Summarize Performance Metrics by Day',
                    @subsystem = 'TSQL',                               
                    @command = 'EXEC [SummarizeMetricsBySystemByDay]', 
                    @database_name = @Database,                                            
                    @retry_attempts = 0,
                    @retry_interval = 0,
                    @on_success_action = 1,
                    @on_fail_action = 2

-- Add the job schedules
-- It runs every hour.
EXECUTE msdb.dbo.sp_add_jobschedule @job_id = @JobID, 
                        @name = N'OrchestratorReporting Summarize Performance Metrics Schedule',  
                        @freq_type = 4,                                                     
                        @freq_interval = 1,                                                
                        @freq_recurrence_factor = 0,                                        
                        @freq_subday_type = 8,                                              
                        @freq_subday_interval = 1                                         

-- Add the Target Servers
EXECUTE msdb.dbo.sp_add_jobserver @job_id = @JobID, 
                                  @server_name = N'(local)' 

GO



-------------------------------------------------------
--
--  OrchestratorReporting - Summarize Process Data
--
-------------------------------------------------------
DECLARE @JobID uniqueidentifier
DECLARE @Database varchar(255)
Set @Database = '<INSERT REPORTING DB NAME HERE>'

SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'OrchestratorReporting - Summarize Process Data')       

IF (@JobID IS NOT NULL)    
BEGIN  
    -- Delete the job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'OrchestratorReporting - Summarize Process Data' 
    SET @JobID = NULL
END 

-- Add the job
EXEC msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , 
                    @job_name = N'OrchestratorReporting - Summarize Process Data',
   			        @enabled = 1,                               
                    @description = N'It summarizes process instance data.',
			        @notify_level_eventlog = 2

-- step 1. Summarize process instances by Hour
EXEC msdb.dbo.sp_add_jobstep @job_id = @JobID, 
                    @step_name = N'Summarize process instances by hour',
                    @subsystem = 'TSQL',                                                   
                    @command = 'EXEC [SummarizeProcessInstanceByHour]', 
                    @database_name = @Database,                                            
                    @retry_attempts = 0,                                                    
                    @retry_interval = 0,                                                    
                    @on_success_action = 1,                                                 
                    @on_fail_action = 2                                                     

-- Add the job schedules
-- It runs every 2 hours.
EXECUTE msdb.dbo.sp_add_jobschedule @job_id = @JobID, 
                        @name = N'OrchestratorReporting Summarize Process Data Schedule',  
                        @freq_type = 4,                                                     
                        @freq_interval = 1,                                                
                        @freq_recurrence_factor = 0,                                        
                        @freq_subday_type = 8,                                              
                        @freq_subday_interval = 2                                         

-- Add the Target Servers
EXECUTE msdb.dbo.sp_add_jobserver @job_id = @JobID, 
                                  @server_name = N'(local)' 

GO

